#cfunction [psd] = get_PSD_feature_Springer_HMM(data, sampling_frequency, frequency_limit_low, frequency_limit_high, figures)
#
# PSD-based feature extraction for heart sound segmentation.
#
## INPUTS:
# data: this is the audio waveform
# sampling_frequency is self-explanatory
# frequency_limit_low is the lower-bound on the frequency range you want to
# analyse
# frequency_limit_high is the upper-bound on the frequency range
# figures: (optional) boolean variable to display figures
#
## OUTPUTS:
# psd is the array of maximum PSD values between the max and min limits,
# resampled to the same size as the original data.
#
# This code was developed by David Springer in the paper:
# D. Springer et al., "Logistic Regression-HSMM-based Heart Sound
# Segmentation," IEEE Trans. Biomed. Eng., In Press, 2015.
#
## Copyright (C) 2016  David Springer
# dave.springer@gmail.com
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import numpy as np
from scipy.signal import spectrogram
from matplotlib import mlab

import scipy
def get_PSD_feature_Springer_HMM(data,sampling_frequency,frequency_limit_low ,frequency_limit_high):
    # Find the spectrogram of the signal:
    # F,T,P = scipy.signal.spectrogram(data,sampling_frequency / 40,int(np.round(sampling_frequency / 80)),np.arange(0,np.round(sampling_frequency / 2),1),sampling_frequency)
    data = np.squeeze(data)
    # P, F, T = mlab.specgram(data, NFFT=500, Fs=sampling_frequency, window = np.hamming(500),noverlap=int(np.ceil(sampling_frequency / 80)),mode='psd')
    # F, T, P = scipy.signal.spectrogram(data, fs=sampling_frequency, window = scipy.signal.windows.hamming(M=int(sampling_frequency/40), sym=True) , noverlap=int(np.ceil(sampling_frequency / 80)), nfft=int(sampling_frequency), return_onesided=True, mode='psd')
    # F, T, P = scipy.signal.spectrogram(data, detrend=False,scaling='density', axis=0,fs=sampling_frequency, window = scipy.signal.windows.hamming(M=int(sampling_frequency/40), sym=False), noverlap=int(np.ceil(sampling_frequency / 80)), nfft=int(sampling_frequency), return_onesided=True, mode='psd')
    # X, WINDOW, NOVERLAP, F, Fs
    WINDOW = 25
    NOVERLAP = 13
    NFFT = int(sampling_frequency)
    Fs = sampling_frequency

    F, T, P  = spectrogram(data, fs=Fs, window='hann', nperseg=WINDOW,noverlap=NOVERLAP, nfft=NFFT, detrend=False,mode='magnitude')
    low_limit_position = np.min(np.abs(F - frequency_limit_low))
    A = list(np.abs(F - frequency_limit_low))
    low_limit_position = A.index(min(A))
    B =  list(np.abs(F - frequency_limit_high))
    high_limit_position = B.index(min(B))
    # Find the mean PSD over the frequency range of interest:
    psd = np.mean(P[np.arange(low_limit_position,high_limit_position+1),:], axis = 0)
    return psd
